@@ -61,7 +61,7 @@
 - (id) initWithDelegate: (id)aDelegate
 		   name: (NSString *)name
 {
-  Display *dpy = [XGServer currentXDisplay];
+  Display *dpy = [XGServer xDisplay];
   return [self initWithDelegate: aDelegate display: dpy name: name];
 }
 
@@ -380,7 +380,7 @@ betterStyle(XIMStyle a, XIMStyle b, XIMStyle xim_requested_style)
     }
   else if (xim_style == OffTheSpotStyle || xim_style == OverTheSpotStyle)
     {
-      Display	    *dpy = [XGServer currentXDisplay];
+      Display	    *dpy = [XGServer xDisplay];
       XFontSet	    font_set;
       char	    **missing_charset;
       int	    num_missing_charset;
@@ -556,7 +556,7 @@ finish:
 
   if (XGetICValues(xics[num_xics - 1], XNClientWindow, &win, NULL))
     return NO;
-  dpy = [XGServer currentXDisplay];
+  dpy = [XGServer xDisplay];
   if (XTranslateCoordinates(dpy, win, DefaultRootWindow(dpy), 0, 0,
 			    &abs_x, &abs_y, &dummy) == 0)
     return NO;
